@@ -610,7 +610,7 @@ application_add_key (Application *application, const char *key,
 			next_value = strtok (NULL, ", \t");
 		}
 		g_free(value_copy);
-		return;		   
+		/* fall through so that we can store the values as keys too */
 	}
 	else if (strcmp (key, "expects_uris") == 0) {
 		if (strcmp (value, "non-file") == 0) {
@@ -1465,8 +1465,9 @@ gnome_vfs_application_registry_unset_key (const char *app_id,
 static void
 cb_application_collect (gpointer key, gpointer value, gpointer user_data)
 {
-	GList **list = user_data;
-	*list = g_list_prepend (*list, value);
+	Application  *application = value;
+	GList       **list = user_data;
+	*list = g_list_prepend (*list, application->app_id);
 }
 
 /**
