@@ -2557,7 +2557,8 @@ vfs_module_init (const char *method_name,
 
 	gl_mutex = g_mutex_new ();
 	
-	gconf_client_add_dir (gl_client, PATH_GCONF_GNOME_VFS, GCONF_CLIENT_PRELOAD_NONE, &gconf_error);
+	gconf_client_add_dir (gl_client, PATH_GCONF_GNOME_VFS, GCONF_CLIENT_PRELOAD_ONELEVEL, &gconf_error);
+	g_signal_connect (G_OBJECT (gl_client), "value_changed", G_CALLBACK (sig_gconf_value_changed), NULL);
 
 	if (gconf_error) {
 		DEBUG_HTTP (("GConf error during client_add_dir '%s'", gconf_error->message));
